@@ -1,7 +1,8 @@
 #####################################################################
 # handle non-invariance of multiple group parameters
 gdina_proc_noninvariance_multiple_groups <- function( data , q.matrix , invariance ,
-	group ){	
+	group )
+{	
 	if ( ( ! is.null(group) ) & ( ! invariance ) ){
 		I <- ncol(data)
 		data <- item_by_group(dat = data, group=group)
