@@ -72,12 +72,13 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	mean.constraint=NULL , Sigma.constraint=NULL , 
     delta.designmatrix=NULL, standardized.latent=FALSE , 
 	centered.latent=FALSE , centerintercepts=FALSE , centerslopes=FALSE , 
-    maxiter=1000, conv=10^(-5), globconv=10^(-5), msteps=4 , 
+    maxiter=1000, conv=1E-5, globconv=1E-5, msteps=4 , 
 	convM=.0005 , 
 	decrease.increments = FALSE , use.freqpatt=FALSE ,
-	progress=TRUE  , ...){	
-# mean.constraint [ dimension , group , value ]
-# Sigma.constraint [ dimension1 , dimension2 , group , value ]		
+	progress=TRUE  , ...)
+{	
+	# mean.constraint [ dimension , group , value ]
+	# Sigma.constraint [ dimension1 , dimension2 , group , value ]		
 	#*************************
 	# data preparation
 	s1 <- Sys.time()
@@ -95,19 +96,22 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	dat0 <- dat
 	# center slopes
 	if ( irtmodel!="2PL" ){ centerslopes <- FALSE }	
-	# use frequency pattern. If yes, then some
-	# data preparation follows.
+	# use frequency pattern. If yes, then some data preparation follows.
 	if ( use.freqpatt ){
-		res <- .gdm.data.prep( dat , data , weights , group )
-		.attach.environment( res , envir=e1 )
-				}
+		res <- gdm_data_prep( dat=dat, data=data, weights=weights, group=group ) 
+		weights <- res$weights
+		dat <- res$dat
+		dat.resp <- res$dat.resp
+		data <- res$data
+		item.patt <- res$item.patt
+	}
 	# maximal categories
 	K <- max(dat)
 	# list of indicator data frames
 	dat.ind <- as.list( 1:(K+1) )
 	for (ii in 0:K){
 		dat.ind[[ii+1]] <- 1 * ( dat==ii )*dat.resp
-				}
+	}
 	I <- ncol(dat)	# number of items
 	n <- nrow(dat)
 	
@@ -115,17 +119,16 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	if ( is.null(group)){ 
 		G <- 1 
 		group0 <- group <- rep(1,n)
-				} 
-			else {
+	} else {
 		group0 <- group
-	  if( ! ( is.numeric(group) ) ){
+		if( ! ( is.numeric(group) ) ){
 			gr2 <- unique( sort(paste( group ) ))
-			    } else {
-		gr2 <- unique( sort( group ) )
-						}
+		} else {
+			gr2 <- unique( sort( group ) )
+		}
 		G <- length(gr2)
 		group <- match( group , gr2 )
-							}
+	}
 	group.stat <- NULL
 	if (G>1){
 		a1 <- stats::aggregate( 1+0*group , list(group) , sum )
@@ -136,11 +139,17 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 		group.stat <- cbind( a2 , a1 )
 		colnames(group.stat) <- c(  "group.orig" , "group" , "N"  )
 	    Ngroup <- a1[,2]		
-			}	
+	}	
     if (G==1){ Ngroup <- length(group) }
-	# theta design
-	res <- .gdm.thetadesign( theta.k , thetaDes , Qmatrix )
-	.attach.environment( res , envir=e1 )
+	
+	#--- theta design
+	res <- gdm_thetadesign( theta.k=theta.k, thetaDes=thetaDes, Qmatrix=Qmatrix ) 
+	D <- res$D
+	TD <- res$TD
+	TP <- res$TP
+	theta.k <- res$theta.k
+	thetaDes <- res$thetaDes
+	Qmatrix <- res$Qmatrix
 	
 	#****
 	# arrange b parameters and starting values
@@ -148,16 +157,7 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	for (ii in 1:K){	# ii <- 1
 		cm1 <- colMeans( ( dat0 >= ii )*dat.resp0 )
 		b[,ii] <-  stats::qlogis( ( cm1 + .01 ) / 1.02 )
-				}	
-	# define some item parameter constraints here
-#	if ( is.null( b.constraint ) & (skillspace=="loglinear") &
-#	     	(irtmodel=="1PL") ){
-#		b.constraint <- matrix( 0 , nrow=1,ncol=3)
-#		b.constraint[ 1 , 1:2 ] <- c( which.min( abs( b ) )[1]  ,1)
-#		b.constraint[ 1 , 3 ] <- 0
-#					}
-
-# print("p300")						
+	}	
 
 	#****
 	# item slope matrix
@@ -166,31 +166,26 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	# item x category slopes are in principle also possible
 	KK <- K	# if KK == 1 then a slope parameter for all items is estimated
 	a <- array( 1 , dim=c(I,TD,KK) )
-# print("a310")
 	# define Q matrix
-	res <- .gdm.Qmatrix(Qmatrix,irtmodel,I,TD,K,a)
-	.attach.environment( res , envir=e1 )
+	res <- gdm_Qmatrix( Qmatrix=Qmatrix, irtmodel=irtmodel, I=I, TD=TD, K=K, a=a ) 
+	Qmatrix <- res$Qmatrix
+	a <- res$a
 
 	# constraints on item parameters
-	res <- .gdm.constraints.itempars( b.constraint , a.constraint , 
-			K , TD , Qmatrix , a)	
-	.attach.environment( res , envir=e1 )	
-
-#	res <- .gdm.constraints.itempars2( b.constraint , a.constraint , K , TD ,I , dat )	
-#	.attach.environment( res , envir=e1 )	
-
-# print("p320")
+	res <- gdm_constraints_itempars( b.constraint=b.constraint, a.constraint=a.constraint, K=K, TD=TD, 
+				Qmatrix=Qmatrix, a=a ) 
+	a.constraint <- res$a.constraint
+	b.constraint <- res$b.constraint
+	a <- res$a
 	
 	# starting values for distributions
 	Sigma <- diag(1,D)
-#	library(mvtnorm)
-	pik <- mvtnorm::dmvnorm( matrix( theta.k ,ncol=D) , 
-				mean=rep(0,D) , sigma = Sigma )
+	pik <- mvtnorm::dmvnorm( matrix( theta.k ,ncol=D) , mean=rep(0,D) , sigma = Sigma )
 	pi.k <- matrix( 0 , TP , G )
-	for (gg in 1:G){ pi.k[,gg] <- pik }
+	for (gg in 1:G){ 
+		pi.k[,gg] <- pik 
+	}
 	n.ik <- array( 0 , dim=c(TP,I,K+1,G) )	
-
-# print("p340")
 	
 	#***
 	# response patterns
@@ -204,9 +199,11 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	
 	#****
 	# create thetaDes design matrix for loglinear smoothing
-	res <- .gdm.create.delta.designmatrix( delta.designmatrix , 
-			TP , D , theta.k , skill.levels,G)	
-	.attach.environment( res , envir=e1 )
+	res <- gdm_create_delta_designmatrix( delta.designmatrix=delta.designmatrix, TP=TP, D=D, theta.k=theta.k, 
+				skill.levels=skill.levels, G=G ) 
+	delta <- res$delta
+	covdelta <- res$covdelta
+	delta.designmatrix <- res$delta.designmatrix
 		
 	se.a <- 0*a
 	max.increment.a <- .3
@@ -216,18 +213,20 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 		mean.constraint <- rbind( mean.constraint , cbind( 1:D , 1 , 0 )  )
 		Sigma.constraint <- rbind( Sigma.constraint , cbind( 1:D , 1:D , 1 , 1 ) )
 		skillspace <- "normal"
-		}
+	}
 	if ( centered.latent ){
 		mean.constraint <- rbind( mean.constraint , cbind( 1:D , 1 , 0 )  )
 		skillspace <- "normal"
-		}
+	}
 	
 	#***
 	# set constraints for a and b parameters if the maximal 
 	# item category differs from item to item
-	res <- .gdm.constraints.itempars2( b.constraint , a.constraint , K , TD , I ,
-				dat )	
-	.attach.environment( res , envir=e1 )
+	res <- gdm_constraints_itempars2( b.constraint=b.constraint, a.constraint=a.constraint, K=K, TD=TD, I=I, dat=dat ) 
+	K.item <- res$K.item
+	a.constraint <- res$a.constraint
+	b.constraint <- res$b.constraint
+	
 	#***
 	# preparations for calc.counts
 	dat.ind2 <- as.list( 1:(K+1) )
@@ -252,9 +251,7 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 						}   # end gg
 			dat.ind2[[kk]] <- l1
 					}
-
-# print("p400")					
-					
+						
 	#---
 	# initial values algorithm
 	dev <- 0	; iter <- 0
@@ -271,220 +268,167 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 		# collect old parameters
 		b0 <- b ; a0 <- a ; dev0 <- dev
 		delta0 <- delta ; pi.k0 <- pi.k
-
- # z0 <- Sys.time()
  		
 		#****
 		#1 calculate probabilities
-		probs <- .gdm.calc.prob( a,b,thetaDes,Qmatrix,I,K,TP,TD)
- 
-  # cat("calc.prob") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1		
- 
+		probs <- gdm_calc_prob( a=a, b=b, thetaDes=thetaDes, Qmatrix=Qmatrix, I=I, K=K, TP=TP, TD=TD ) 
  
 		#*****
 		#2 calculate individual likelihood
 		h1 <- matrix( 1 , nrow=n , ncol=TP )
-		res.hwt <- calc_posterior.v2(rprobs= probs , gwt=h1 , 
-					 resp=dat , nitems= I , 
-					 resp.ind.list=resp.ind.list , normalization=FALSE , 
-					 thetasamp.density= NULL , snodes=0 )	
+		res.hwt <- cdm_calc_posterior( rprobs=probs, gwt=h1, resp=dat, nitems=I, resp.ind.list=resp.ind.list, 
+						normalization=FALSE, thetasamp.density=NULL, snodes=0 ) 
 		p.xi.aj <- res.hwt$hwt 	
-
-# cat("calc.like") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1	
 		
 		#*****
 		#3 calculate posterior and marginal distributions
-		res <- .gdm.calc.post(pi.k,group,p.xi.aj,weights,G,ind.group,
-				use.freqpatt )
+		res <- gdm_calc_post( pi.k=pi.k, group=group, p.xi.aj=p.xi.aj, weights=weights, G=G, 
+					ind.group=ind.group, use.freqpatt=use.freqpatt ) 
 		p.aj.xi <- res$p.aj.xi
 		pi.k <- res$pi.k
-
-
-# cat("calc.post") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1	
 		
 		#*****
 		#4 calculate expected counts
 		# n.ik [ 1:TP , 1:I , 1:(K+1) , 1:G ]
-		res <- .gdm.calc.counts(G,weights,dat.ind,dat,
-					dat.resp,p.aj.xi,K,n.ik,TP,I,group , dat.ind2 , ind.group ,
-					use.freqpatt )		
+		res <- gdm_calc_counts( G=G, weights=weights, dat.ind=dat.ind, dat=dat, dat.resp=dat.resp, 
+					p.aj.xi=p.aj.xi, K=K, n.ik=n.ik, TP=TP, I=I, group=group, dat.ind2=dat.ind2, 
+					ind.group=ind.group, use.freqpatt=use.freqpatt ) 		
 		n.ik <- res$n.ik
 		N.ik <- res$N.ik
 
-# cat("calc.counts") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1		
-
 		#*****
 		#5 M step: b parameter estimation
 		# n.ik  [1:TP,1:I,1:K,1:G]
 		# probs[1:I,1:K,1:TP]
-		res <- .gdm.est.b(probs, n.ik, N.ik, I, K, G,b,b.constraint,
-				max.increment=max.increment.b , a,thetaDes,Qmatrix,TP,TD,
-				msteps,convM , centerintercepts )	
+		res <- gdm_est_b( probs=probs, n.ik=n.ik, N.ik=N.ik, I=I, K=K, G=G, b=b, b.constraint=b.constraint, 
+					max.increment=max.increment.b, a=a, thetaDes=thetaDes, Qmatrix=Qmatrix, TP=TP, 
+					TD=TD, msteps=msteps, convM=convM, centerintercepts=centerintercepts, 
+					decrease.increments=decrease.increments ) 	
 		b <- res$b
 		se.b <- res$se.b
-		if (decrease.increments){ 	max.increment.b <- res$max.increment.b/1.01	}
-		
-# cat("est b") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1		
+		max.increment.b <- res$max.increment.b		
 		
 		#*****
 		#6 M step: a parameter estimation	
 		if ( irtmodel == "2PL"){
-			res <- .gdm.est.a(probs, n.ik, N.ik, I, K, G,a,a.constraint,TD,
-					Qmatrix,thetaDes,TP, max.increment = max.increment.a ,
-					b , msteps , convM , centerslopes )
+			res <- gdm_est_a( probs=probs, n.ik=n.ik, N.ik=N.ik, I=I, K=K, G=G, a=a, a.constraint=a.constraint, 
+						TD=TD, Qmatrix=Qmatrix, thetaDes=thetaDes, TP=TP, max.increment=max.increment.a, b=b, 
+						msteps=msteps, convM=convM, centerslopes=centerslopes, decrease.increments=decrease.increments ) 
 			a <- res$a						
 			se.a <- res$se.a
-			if (decrease.increments){ 	max.increment.a <- res$max.increment.a/1.01	}
-						}
+			max.increment.a <- res$max.increment.a
+		}
 					
 		if ( irtmodel == "2PLcat"){
-			res <- .gdm.est.a.cat(probs, n.ik, N.ik, I, K, G,a,a.constraint,TD,
-					Qmatrix,thetaDes,TP, max.increment = max.increment.a ,
-					b , msteps , convM )					
+			res <- gdm_est_a_cat( probs=probs, n.ik=n.ik, N.ik=N.ik, I=I, K=K, G=G, a=a, a.constraint=a.constraint, 
+						TD=TD, Qmatrix=Qmatrix, thetaDes=thetaDes, TP=TP, max.increment=max.increment.a, b=b, msteps=msteps, 
+						convM=convM, decrease.increments=decrease.increments ) 					
 			a <- res$a
 			se.a <- res$se.a
-			if (decrease.increments){ 	
-				max.increment.a <- res$max.increment.a / 1.01				
-					}
-						}	
-			
-# cat("est a") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1		
+			max.increment.a <- res$max.increment.a
+		}				
 						
 		#*****
-		#7 M step: estimate reduced skillspace
-	
+		#7 M step: estimate reduced skillspace	
 		if ( skillspace == "loglinear" ){
-			res <- .gdm.est.skillspace(Ngroup, pi.k , Z=delta.designmatrix ,
-					G , delta  )
+			res <- gdm_est_skillspace( Ngroup=Ngroup, pi.k=pi.k, Z=delta.designmatrix, G=G, delta=delta ) 
 			pi.k <- res$pi.k
 			delta <- res$delta
 			covdelta <- res$covdelta
-					}
+		}
 		if ( skillspace == "normal" ){	
-			res <- .gdm.est.normalskills( pi.k , theta.k , irtmodel,
-						G,D , mean.constraint , Sigma.constraint ,
-						standardized.latent	, p.aj.xi , group , ind.group  ,
-						weights , b , a)
+			res <- gdm_est_normalskills( pi.k=pi.k, theta.k=theta.k, irtmodel=irtmodel, G=G, D=D, 
+						mean.constraint=mean.constraint, Sigma.constraint=Sigma.constraint, 
+						standardized.latent=standardized.latent, p.aj.xi=p.aj.xi, group=group, ind.group=ind.group, 
+						weights=weights, b=b, a=a ) 
 			pi.k <- res$pi.k
 			b <- res$b 
-			a <- res$a
-			
-					}
-
+			a <- res$a			
+		}
 					
 		# estimate skillspace		
         if ( skillspace == "est" ){
-			res <- .gdm.est.skillspace.traits( n.ik , a , b , theta.k , Qmatrix , I , K , TP,
-					TD , numdiff.parm=.001 , max.increment=1 , msteps , convM )
+			res <- gdm_est_skillspace_traits( n.ik=n.ik, a=a, b=b, theta.k=theta.k, Qmatrix=Qmatrix, I=I, K=K, TP=TP, TD=TD, 
+						numdiff.parm=.001, max.increment=1, msteps=msteps, convM=convM ) 
 			theta.k <- res$theta.k
 			se.theta.k <- res$se.theta.k
 			thetaDes <- theta.k
-						}
-# cat("skillspace") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1		
-
+		}
 			
 		#*****
 		#8 calculate likelihood
-		# n.ik [ TP , I , K+1 , G ]
-		# N.ik [ TP , I , G ]
-		# probs [I , K+1 , TP ]
-		ll <- 0
-		for (gg in 1:G){ 
-#			ind.gg <- which(group==gg)
-			if ( ! use.freqpatt ){
-				ind.gg <- ind.group[[gg]]
-				ll <- ll + sum( weights[ind.gg] * log( rowSums( p.xi.aj[ind.gg,] * 
-							matrix( pi.k[,gg] , nrow= length(ind.gg) , ncol=nrow(pi.k) , byrow=TRUE ) ) ) )
-									}
-			if ( use.freqpatt ){
-			  if (G>1){   wgg <- weights[,gg]  }
-			  if (G==1){ wgg <- weights }
-				ll <- ll + sum( wgg * log( rowSums( p.xi.aj * 
-							matrix( pi.k[,gg] , nrow= nrow(p.xi.aj) , 
-									ncol=nrow(pi.k) , byrow=TRUE ) ) ) )
-									}
-							
-							}
-		dev <- -2*ll	
-
-#  cat("calc LL") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1		
+		res <- gdm_calc_deviance( G=G, use.freqpatt=use.freqpatt, ind.group=ind.group, p.xi.aj=p.xi.aj, 
+					pi.k=pi.k, weights=weights ) 
+		ll <- res$ll
+		dev <- res$dev
 
 		#~~~~~~~~~~~~~~~~~~~~~~~~~~
 		# display progress		
-		gg0 <- abs( a - a0 )
-		gg1 <- abs( b - b0 )
-		pardiff <- max( gg1 , gg0 )
-		deltadiff <- abs( pi.k - pi.k0 )	
+		a_change <- gg0 <- max(abs( a - a0 ))
+		b_change <- gg1 <- max(abs( b - b0 ))
+		pardiff <- max( b_change , a_change )
+		deltadiff <- max( abs( pi.k - pi.k0 ))
 		conv1 <- max( c(pardiff,deltadiff))
 		globconv1 <- abs( dev - dev0) 
-		iter <- iter +1
-		if (progress){
-			cat(disp)	
-			cat("Iteration" , iter , "   " , paste( Sys.time() ) , "\n" )		
-			cat( paste( "   Deviance = "  , 
-					   round( dev , 4 ) , 
-					  if (iter > 1 ){ " | Deviance change = " } else {""} ,
-							 if( iter>1){round( - dev + dev0 , 6 )} else { ""}	,sep=""))
-			if ( dev > dev0 & (iter>1 ) ){ cat( "  Deviance increases!") } ; cat("\n")
-			cat( paste( "    Maximum item intercept parameter change = " , 
-								 round( max( gg1) , 6 ) ,  " \n"   )  )  
-			cat( paste( "    Maximum item slope parameter change = " , 
-								 round( max( gg0 ) , 6 ) ,  " \n"   )  )  							 
-			cat( paste( "    Maximum distribution parameter change = " , 
-								 round( max( deltadiff ) , 6 ) ,  " \n"   )  )  
-			utils::flush.console()							 
-					}
-				
-								}
-		############################################
-		# END MML Algorithm
-		############################################
+		iter <- iter + 1
 		
-		# collect item parameters
-		res <- .gdm.collect.itempars( data , K , D , b , a , TD , thetaDes ,
-					irtmodel , se.b , se.a , data0)
-		.attach.environment( res , envir=e1 )					
+		res <- gdm_progress_em_algorithm( progress=progress, disp=disp, iter=iter, dev=dev, dev0=dev0, b_change=b_change, 
+					a_change=a_change, deltadiff=deltadiff ) 
+	}
+	############################################
+	# END MML Algorithm
+	############################################
 		
-		# calculate distribution properties
-		res <- .gdm.calc.distributionmoments( D , G , pi.k , theta.k )
-		.attach.environment( res , envir=e1 )	
+	# collect item parameters
+	res <- gdm_collect_itempars( data=data, K=K, D=D, b=b, a=a, TD=TD, thetaDes=thetaDes, irtmodel=irtmodel, se.b=se.b, 
+				se.a=se.a, data0=data0 ) 
+	item <- res$item
+	b <- res$b
+	se.b <- res$se.b
+	a <- res$a					
 		
-		# Information criteria
-		ic <- .gdm.calc.ic( dev , dat , G , skillspace , irtmodel , 
-				K,D,TD,I,b.constraint,a.constraint,mean.constraint ,
-			    Sigma.constraint, delta.designmatrix , standardized.latent ,
-				data0 , centerslopes , TP , centerintercepts )
+	# calculate distribution properties
+	res <- gdm_calc_distributionmoments( D=D, G=G, pi.k=pi.k, theta.k=theta.k ) 
+	mean.trait <- res$mean.trait
+	sd.trait <- res$sd.trait
+	skewness.trait <- res$skewness.trait
+	correlation.trait <- res$correlation.trait
+			
+	# Information criteria
+	ic <- gdm_calc_ic( dev=dev, dat=dat, G=G, skillspace=skillspace, irtmodel=irtmodel, K=K, D=D, TD=TD, I=I, 
+				b.constraint=b.constraint, a.constraint=a.constraint, mean.constraint=mean.constraint, 
+				Sigma.constraint=Sigma.constraint, delta.designmatrix=delta.designmatrix, 
+				standardized.latent=standardized.latent, data0=data0, centerslopes=centerslopes, TP=TP, 
+				centerintercepts=centerintercepts ) 
 
 	#########################################
 	# item fit [ items , theta , categories ] 
 	# # n.ik [ 1:TP , 1:I , 1:(K+1) , 1:G ]
 	probs <- aperm( probs , c(3,1,2) )
-	itemfit.rmsea <- itemfit.rmsea( n.ik , pi.k , probs ,
-			itemnames = colnames(data) )		
+	itemfit.rmsea <- itemfit.rmsea( n.ik , pi.k , probs , itemnames = colnames(data) )		
     item$itemfit.rmsea <- itemfit.rmsea$rmsea
 	rownames(item) <- NULL
 	
 	# person parameters
-	person <- NULL
-	res <- .gdm.person.parameters( data , D , theta.k , p.xi.aj , p.aj.xi , weights )	
-	.attach.environment( res , envir=e1 )
-	
-	
+	res <- gdm_person_parameters( data=data, D=D, theta.k=theta.k, p.xi.aj=p.xi.aj, p.aj.xi=p.aj.xi, weights=weights ) 
+	person <- res$person
+	EAP.rel <- res$EAP.rel
+		
 	#*************************
 	# collect output	
 	s2 <- Sys.time()
-	res <- list( "item" = item , "person" = person , "EAP.rel" = EAP.rel , 
-				"deviance"=dev , "ic" = ic , "b" = b , "se.b" = se.b , 
-				"a" = a ,  "se.a" = se.a , 
-				"itemfit.rmsea" = itemfit.rmsea , 
-				"mean.rmsea" = mean(itemfit.rmsea$rmsea) , 				
-				"Qmatrix"=Qmatrix , "pi.k"=pi.k , 	
-				"mean.trait"=mean.trait , "sd.trait" = sd.trait , 
-				"skewness.trait" = skewness.trait , "correlation.trait" = correlation.trait , 
-				"pjk" = probs , "n.ik" = n.ik ,  
-				"G"=G , "D"=D , "I" = ncol(data) , "N" = nrow(data) , 
-				"delta" = delta , "covdelta"=covdelta , "data" = data ,
-				"group.stat"=group.stat )
+	res <- list( item = item , person = person , EAP.rel = EAP.rel , 
+				deviance=dev , ic = ic , b = b , se.b = se.b , 
+				a = a ,  se.a = se.a , 
+				itemfit.rmsea = itemfit.rmsea , 
+				mean.rmsea = mean(itemfit.rmsea$rmsea) , 				
+				Qmatrix=Qmatrix , pi.k=pi.k , 	
+				mean.trait=mean.trait , sd.trait = sd.trait , 
+				skewness.trait = skewness.trait , correlation.trait = correlation.trait , 
+				pjk = probs , n.ik = n.ik ,  
+				G=G , D=D , I = ncol(data) , N = nrow(data) , 
+				delta = delta , covdelta=covdelta , data = data ,
+				group.stat=group.stat )
 	res$p.xi.aj <- p.xi.aj ; res$posterior <- p.aj.xi 
 	res$skill.levels <- skill.levels
 	res$K.item <- K.item
@@ -492,7 +436,7 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	res$thetaDes <- thetaDes
 	res$se.theta.k <- NULL
 	res$group <- group
-	res$time <- list( "s1"=s1,"s2"=s2 , "timediff"=s2-s1)
+	res$time <- list( s1=s1,s2=s2 , timediff=s2-s1)
 	res$skillspace <- skillspace
 	res$iter <- iter
 	res$converged <- iter < maxiter 
@@ -508,15 +452,14 @@ gdm <- function( data , theta.k, irtmodel="2PL", group=NULL,
 	res$control$group <- group
 	
 	if (progress){
-                cat("----------------------------------- \n")
-                cat("Start:" , paste( s1) , "\n")
-                cat("End:" , paste(s2) , "\n")
-                cat("Difference:" , print(s2 -s1), "\n")
-                cat("----------------------------------- \n")
-				  }
+        cat("----------------------------------- \n")
+        cat("Start:" , paste( s1) , "\n")
+        cat("End:" , paste(s2) , "\n")
+        cat("Difference:" , print(s2 -s1), "\n")
+        cat("----------------------------------- \n")
+	}
 	class(res) <- "gdm"
 	res$call <- cl
-	return(res)
-				
-		}		
+	return(res)				
+}		
 ###################################################
