@@ -3,7 +3,11 @@
 ################################################################################
 print.din <-
 function(x, ... ){
-	cat("Estimation of Mixed DINA/DINO Model\n")
+	cat("Estimation of Mixed DINA/DINO Model\n\n")
+
+    d1 <- utils::packageDescription("CDM")
+	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n" )		
+	
 	cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), 
 				"\n\n", sep = "")
 	#*** parameters
@@ -12,8 +16,8 @@ function(x, ... ){
 	cat(paste0("Number of skill dimensions = " , ncol(x$q.matrix) , "\n") )	
 	cat(paste0("Number of skill classes = " , nrow(x$attribute.patt) , "\n") )		
 	cat(paste0("Number of parameters = " , sum(x$Npars) , "\n") )
-	cat(paste0("  Number of item parameters = " , x$Npars$itempars , "\n") )
-	cat(paste0("  Number of skill distribution parameters = " , 
+	cat(paste0("  # item parameters = " , x$Npars$itempars , "\n") )
+	cat(paste0("  # skill distribution parameters = " , 
 				x$Npars$skillpars , "\n") )
 	#*** likelihood
 	cat( paste0( "\nLog-Likelihood = " , round( x$loglike ,2 ) , "\n") )
