@@ -1,16 +1,16 @@
 
 summary.IRT.RMSD_print_statistics <- function( stat_summary, stat, digits){
 	obji <- stat_summary
-	NC <- base::ncol(obji)
+	NC <- ncol(obji)
 	for (gg in 2:NC ){
-		obji[,gg] <- base::round( obji[,gg] , digits=digits)
+		obji[,gg] <- round( obji[,gg] , digits=digits)
 	}
 	print( obji )   	
 	cat("\n")
 	obji <- stat
-	NC <- base::ncol(obji)
+	NC <- ncol(obji)
 	for (gg in 2:NC ){
-		obji[,gg] <- base::round( obji[,gg] , digits=digits)
+		obji[,gg] <- round( obji[,gg] , digits=digits)
 	}
 	print( obji )   
-}
\ No newline at end of file
+}
